==> nhc98src-1.18.tar.gz: nhc98-1.18/src/prelude/Prelude/CBounded.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define CT_v180	((void*)startLabel+84)
#define FN_LAMBDA173	((void*)startLabel+128)
#define CT_v184	((void*)startLabel+172)
#define CF_LAMBDA173	((void*)startLabel+180)
#define CT_v189	((void*)startLabel+284)
#define FN_LAMBDA174	((void*)startLabel+328)
#define CT_v193	((void*)startLabel+372)
#define CF_LAMBDA174	((void*)startLabel+380)
#define CT_v196	((void*)startLabel+428)
#define CT_v199	((void*)startLabel+484)
#define ST_v183	((void*)startLabel+512)
#define ST_v192	((void*)startLabel+560)
#define ST_v177	((void*)startLabel+608)
#define PP_LAMBDA173	((void*)startLabel+627)
#define PC_LAMBDA173	((void*)startLabel+627)
#define ST_v182	((void*)startLabel+627)
#define ST_v186	((void*)startLabel+652)
#define PP_LAMBDA174	((void*)startLabel+671)
#define PC_LAMBDA174	((void*)startLabel+671)
#define ST_v191	((void*)startLabel+671)
#define ST_v198	((void*)startLabel+696)
#define ST_v195	((void*)startLabel+716)
#define PS_v194	((void*)startLabel+736)
#define PS_v197	((void*)startLabel+748)
#define PS_v188	((void*)startLabel+760)
#define PS_v185	((void*)startLabel+772)
#define PS_v187	((void*)startLabel+784)
#define PS_v179	((void*)startLabel+796)
#define PS_v176	((void*)startLabel+808)
#define PS_v178	((void*)startLabel+820)
#define PS_v181	((void*)startLabel+832)
#define PS_v190	((void*)startLabel+844)
extern Node FN_Prelude_46error[];
extern Node PM_Prelude[];
extern Node PC_Prelude_46error[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v180)
,};
Node FN_Prelude_46_95_46maxBound[] = {
  bytes2word(ZAP_ARG_I1,NEEDHEAP_I32,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,PUSH_HEAP,HEAP_CVAL_P1,8)
, bytes2word(HEAP_CVAL_N1,12,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_OFF_N1,10,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, useLabel(PS_v179)
, 0
, 0
, 0
, 0
, useLabel(PS_v178)
, 0
, 0
, 0
, 0
, 0
, useLabel(ST_v177)
,	/* CT_v180: (byte 0) */
  HW(2,1)
, 0
,};
Node F0_Prelude_46_95_46maxBound[] = {
  CAPTAG(useLabel(FN_Prelude_46_95_46maxBound),1)
, useLabel(PS_v176)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_LAMBDA173))
, VAPTAG(useLabel(FN_Prelude_46error))
, bytes2word(0,0,0,0)
, useLabel(CT_v184)
,	/* FN_LAMBDA173: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,8,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, 0
, 0
, 0
, 0
, useLabel(ST_v183)
, 0
, useLabel(ST_v182)
,	/* CT_v184: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA173: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA173))
, useLabel(PS_v181)
, 0
, 0
, 0
, bytes2word(1,0,0,1)
, useLabel(CT_v189)
,};
Node FN_Prelude_46_95_46minBound[] = {
  bytes2word(ZAP_ARG_I1,NEEDHEAP_I32,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,PUSH_HEAP,HEAP_CVAL_P1,8)
, bytes2word(HEAP_CVAL_N1,12,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_OFF_N1,10,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, useLabel(PS_v188)
, 0
, 0
, 0
, 0
, useLabel(PS_v187)
, 0
, 0
, 0
, 0
, 0
, useLabel(ST_v186)
,	/* CT_v189: (byte 0) */
  HW(2,1)
, 0
,};
Node F0_Prelude_46_95_46minBound[] = {
  CAPTAG(useLabel(FN_Prelude_46_95_46minBound),1)
, useLabel(PS_v185)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_LAMBDA174))
, VAPTAG(useLabel(FN_Prelude_46error))
, bytes2word(0,0,0,0)
, useLabel(CT_v193)
,	/* FN_LAMBDA174: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,8,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, 0
, 0
, 0
, 0
, useLabel(ST_v192)
, 0
, useLabel(ST_v191)
,	/* CT_v193: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA174: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA174))
, useLabel(PS_v190)
, 0
, 0
, 0
, bytes2word(1,0,0,1)
, useLabel(CT_v196)
,};
Node FN_Prelude_46minBound[] = {
  bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,1)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 30007
, useLabel(ST_v195)
,	/* CT_v196: (byte 0) */
  HW(0,1)
, 0
,};
Node F0_Prelude_46minBound[] = {
  CAPTAG(useLabel(FN_Prelude_46minBound),1)
, useLabel(PS_v194)
, 0
, 0
, 0
, bytes2word(1,0,0,1)
, useLabel(CT_v199)
,};
Node FN_Prelude_46maxBound[] = {
  bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,2)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 30007
, useLabel(ST_v198)
,	/* CT_v199: (byte 0) */
  HW(0,1)
, 0
,};
Node F0_Prelude_46maxBound[] = {
  CAPTAG(useLabel(FN_Prelude_46maxBound),1)
, useLabel(PS_v197)
, 0
, 0
, 0
,	/* ST_v183: (byte 0) */
  bytes2word(78,111,32,100)
, bytes2word(101,102,97,117)
, bytes2word(108,116,32,100)
, bytes2word(101,102,105,110)
, bytes2word(105,116,105,111)
, bytes2word(110,32,102,111)
, bytes2word(114,32,99,108)
, bytes2word(97,115,115,32)
, bytes2word(109,101,116,104)
, bytes2word(111,100,32,109)
, bytes2word(97,120,66,111)
,	/* ST_v192: (byte 4) */
  bytes2word(117,110,100,0)
, bytes2word(78,111,32,100)
, bytes2word(101,102,97,117)
, bytes2word(108,116,32,100)
, bytes2word(101,102,105,110)
, bytes2word(105,116,105,111)
, bytes2word(110,32,102,111)
, bytes2word(114,32,99,108)
, bytes2word(97,115,115,32)
, bytes2word(109,101,116,104)
, bytes2word(111,100,32,109)
, bytes2word(105,110,66,111)
, bytes2word(117,110,100,0)
,};
Node PP_Prelude_46_95_46maxBound[] = {
 };
Node PC_Prelude_46_95_46maxBound[] = {
 	/* ST_v177: (byte 0) */
  bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(95,46,109,97)
, bytes2word(120,66,111,117)
,	/* PP_LAMBDA173: (byte 3) */
 	/* PC_LAMBDA173: (byte 3) */
 	/* ST_v182: (byte 3) */
  bytes2word(110,100,0,80)
, bytes2word(114,101,108,117)
, bytes2word(100,101,46,95)
, bytes2word(46,109,97,120)
, bytes2word(66,111,117,110)
, bytes2word(100,58,110,111)
, bytes2word(112,111,115,0)
,};
Node PP_Prelude_46_95_46minBound[] = {
 };
Node PC_Prelude_46_95_46minBound[] = {
 	/* ST_v186: (byte 0) */
  bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(95,46,109,105)
, bytes2word(110,66,111,117)
,	/* PP_LAMBDA174: (byte 3) */
 	/* PC_LAMBDA174: (byte 3) */
 	/* ST_v191: (byte 3) */
  bytes2word(110,100,0,80)
, bytes2word(114,101,108,117)
, bytes2word(100,101,46,95)
, bytes2word(46,109,105,110)
, bytes2word(66,111,117,110)
, bytes2word(100,58,110,111)
, bytes2word(112,111,115,0)
,};
Node PP_Prelude_46maxBound[] = {
 };
Node PC_Prelude_46maxBound[] = {
 	/* ST_v198: (byte 0) */
  bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(109,97,120,66)
, bytes2word(111,117,110,100)
, bytes2word(0,0,0,0)
,};
Node PP_Prelude_46minBound[] = {
 };
Node PC_Prelude_46minBound[] = {
 	/* ST_v195: (byte 0) */
  bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(109,105,110,66)
, bytes2word(111,117,110,100)
, bytes2word(0,0,0,0)
,	/* PS_v194: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46minBound)
, useLabel(PC_Prelude_46minBound)
,	/* PS_v197: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46maxBound)
, useLabel(PC_Prelude_46maxBound)
,	/* PS_v188: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46minBound)
, useLabel(PC_Prelude_46error)
,	/* PS_v185: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46minBound)
, useLabel(PC_Prelude_46_95_46minBound)
,	/* PS_v187: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46minBound)
, useLabel(PC_LAMBDA174)
,	/* PS_v179: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46maxBound)
, useLabel(PC_Prelude_46error)
,	/* PS_v176: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46maxBound)
, useLabel(PC_Prelude_46_95_46maxBound)
,	/* PS_v178: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46maxBound)
, useLabel(PC_LAMBDA173)
,	/* PS_v181: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_LAMBDA173)
, useLabel(PC_LAMBDA173)
,	/* PS_v190: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_LAMBDA174)
, useLabel(PC_LAMBDA174)
,};

==> nhc98src-1.20.tar.gz: nhc98-1.20/src/prelude/Prelude/CBounded.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define CT_v185	((void*)startLabel+84)
#define FN_LAMBDA178	((void*)startLabel+128)
#define CT_v189	((void*)startLabel+172)
#define CF_LAMBDA178	((void*)startLabel+180)
#define CT_v194	((void*)startLabel+284)
#define FN_LAMBDA179	((void*)startLabel+328)
#define CT_v198	((void*)startLabel+372)
#define CF_LAMBDA179	((void*)startLabel+380)
#define CT_v201	((void*)startLabel+428)
#define CT_v204	((void*)startLabel+484)
#define ST_v188	((void*)startLabel+512)
#define ST_v197	((void*)startLabel+560)
#define ST_v182	((void*)startLabel+608)
#define PP_LAMBDA178	((void*)startLabel+627)
#define PC_LAMBDA178	((void*)startLabel+627)
#define ST_v187	((void*)startLabel+627)
#define ST_v191	((void*)startLabel+652)
#define PP_LAMBDA179	((void*)startLabel+671)
#define PC_LAMBDA179	((void*)startLabel+671)
#define ST_v196	((void*)startLabel+671)
#define ST_v203	((void*)startLabel+696)
#define ST_v200	((void*)startLabel+716)
#define PS_v199	((void*)startLabel+736)
#define PS_v202	((void*)startLabel+748)
#define PS_v193	((void*)startLabel+760)
#define PS_v190	((void*)startLabel+772)
#define PS_v192	((void*)startLabel+784)
#define PS_v184	((void*)startLabel+796)
#define PS_v181	((void*)startLabel+808)
#define PS_v183	((void*)startLabel+820)
#define PS_v186	((void*)startLabel+832)
#define PS_v195	((void*)startLabel+844)
extern Node FN_NHC_46Internal_46_95noMethodError[];
extern Node PM_Prelude[];
extern Node PC_NHC_46Internal_46_95noMethodError[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v185)
,};
Node FN_Prelude_46_95_46maxBound[] = {
  bytes2word(ZAP_ARG_I1,NEEDHEAP_I32,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,PUSH_HEAP,HEAP_CVAL_P1,8)
, bytes2word(HEAP_CVAL_N1,12,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_OFF_N1,10,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, useLabel(PS_v184)
, 0
, 0
, 0
, 0
, useLabel(PS_v183)
, 0
, 0
, 0
, 0
, 0
, useLabel(ST_v182)
,	/* CT_v185: (byte 0) */
  HW(2,1)
, 0
,};
Node F0_Prelude_46_95_46maxBound[] = {
  CAPTAG(useLabel(FN_Prelude_46_95_46maxBound),1)
, useLabel(PS_v181)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_LAMBDA178))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95noMethodError))
, bytes2word(0,0,0,0)
, useLabel(CT_v189)
,	/* FN_LAMBDA178: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,8,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, 0
, 0
, 0
, 0
, useLabel(ST_v188)
, 0
, useLabel(ST_v187)
,	/* CT_v189: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA178: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA178))
, useLabel(PS_v186)
, 0
, 0
, 0
, bytes2word(1,0,0,1)
, useLabel(CT_v194)
,};
Node FN_Prelude_46_95_46minBound[] = {
  bytes2word(ZAP_ARG_I1,NEEDHEAP_I32,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,PUSH_HEAP,HEAP_CVAL_P1,8)
, bytes2word(HEAP_CVAL_N1,12,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_OFF_N1,10,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, useLabel(PS_v193)
, 0
, 0
, 0
, 0
, useLabel(PS_v192)
, 0
, 0
, 0
, 0
, 0
, useLabel(ST_v191)
,	/* CT_v194: (byte 0) */
  HW(2,1)
, 0
,};
Node F0_Prelude_46_95_46minBound[] = {
  CAPTAG(useLabel(FN_Prelude_46_95_46minBound),1)
, useLabel(PS_v190)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_LAMBDA179))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95noMethodError))
, bytes2word(0,0,0,0)
, useLabel(CT_v198)
,	/* FN_LAMBDA179: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,8,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, 0
, 0
, 0
, 0
, useLabel(ST_v197)
, 0
, useLabel(ST_v196)
,	/* CT_v198: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA179: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA179))
, useLabel(PS_v195)
, 0
, 0
, 0
, bytes2word(1,0,0,1)
, useLabel(CT_v201)
,};
Node FN_Prelude_46minBound[] = {
  bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,1)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 30007
, useLabel(ST_v200)
,	/* CT_v201: (byte 0) */
  HW(0,1)
, 0
,};
Node F0_Prelude_46minBound[] = {
  CAPTAG(useLabel(FN_Prelude_46minBound),1)
, useLabel(PS_v199)
, 0
, 0
, 0
, bytes2word(1,0,0,1)
, useLabel(CT_v204)
,};
Node FN_Prelude_46maxBound[] = {
  bytes2word(NEEDSTACK_I16,SELECTOR_EVAL,SELECT,2)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 30007
, useLabel(ST_v203)
,	/* CT_v204: (byte 0) */
  HW(0,1)
, 0
,};
Node F0_Prelude_46maxBound[] = {
  CAPTAG(useLabel(FN_Prelude_46maxBound),1)
, useLabel(PS_v202)
, 0
, 0
, 0
,	/* ST_v188: (byte 0) */
  bytes2word(78,111,32,100)
, bytes2word(101,102,97,117)
, bytes2word(108,116,32,100)
, bytes2word(101,102,105,110)
, bytes2word(105,116,105,111)
, bytes2word(110,32,102,111)
, bytes2word(114,32,99,108)
, bytes2word(97,115,115,32)
, bytes2word(109,101,116,104)
, bytes2word(111,100,32,109)
, bytes2word(97,120,66,111)
,	/* ST_v197: (byte 4) */
  bytes2word(117,110,100,0)
, bytes2word(78,111,32,100)
, bytes2word(101,102,97,117)
, bytes2word(108,116,32,100)
, bytes2word(101,102,105,110)
, bytes2word(105,116,105,111)
, bytes2word(110,32,102,111)
, bytes2word(114,32,99,108)
, bytes2word(97,115,115,32)
, bytes2word(109,101,116,104)
, bytes2word(111,100,32,109)
, bytes2word(105,110,66,111)
, bytes2word(117,110,100,0)
,};
Node PP_Prelude_46_95_46maxBound[] = {
 };
Node PC_Prelude_46_95_46maxBound[] = {
 	/* ST_v182: (byte 0) */
  bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(95,46,109,97)
, bytes2word(120,66,111,117)
,	/* PP_LAMBDA178: (byte 3) */
 	/* PC_LAMBDA178: (byte 3) */
 	/* ST_v187: (byte 3) */
  bytes2word(110,100,0,80)
, bytes2word(114,101,108,117)
, bytes2word(100,101,46,95)
, bytes2word(46,109,97,120)
, bytes2word(66,111,117,110)
, bytes2word(100,58,110,111)
, bytes2word(112,111,115,0)
,};
Node PP_Prelude_46_95_46minBound[] = {
 };
Node PC_Prelude_46_95_46minBound[] = {
 	/* ST_v191: (byte 0) */
  bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(95,46,109,105)
, bytes2word(110,66,111,117)
,	/* PP_LAMBDA179: (byte 3) */
 	/* PC_LAMBDA179: (byte 3) */
 	/* ST_v196: (byte 3) */
  bytes2word(110,100,0,80)
, bytes2word(114,101,108,117)
, bytes2word(100,101,46,95)
, bytes2word(46,109,105,110)
, bytes2word(66,111,117,110)
, bytes2word(100,58,110,111)
, bytes2word(112,111,115,0)
,};
Node PP_Prelude_46maxBound[] = {
 };
Node PC_Prelude_46maxBound[] = {
 	/* ST_v203: (byte 0) */
  bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(109,97,120,66)
, bytes2word(111,117,110,100)
, bytes2word(0,0,0,0)
,};
Node PP_Prelude_46minBound[] = {
 };
Node PC_Prelude_46minBound[] = {
 	/* ST_v200: (byte 0) */
  bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(109,105,110,66)
, bytes2word(111,117,110,100)
, bytes2word(0,0,0,0)
,	/* PS_v199: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46minBound)
, useLabel(PC_Prelude_46minBound)
,	/* PS_v202: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46maxBound)
, useLabel(PC_Prelude_46maxBound)
,	/* PS_v193: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46minBound)
, useLabel(PC_NHC_46Internal_46_95noMethodError)
,	/* PS_v190: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46minBound)
, useLabel(PC_Prelude_46_95_46minBound)
,	/* PS_v192: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46minBound)
, useLabel(PC_LAMBDA179)
,	/* PS_v184: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46maxBound)
, useLabel(PC_NHC_46Internal_46_95noMethodError)
,	/* PS_v181: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46maxBound)
, useLabel(PC_Prelude_46_95_46maxBound)
,	/* PS_v183: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46_95_46maxBound)
, useLabel(PC_LAMBDA178)
,	/* PS_v186: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_LAMBDA178)
, useLabel(PC_LAMBDA178)
,	/* PS_v195: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_LAMBDA179)
, useLabel(PC_LAMBDA179)
,};
